@@ -32,10 +32,10 @@ class Oanda():
         self.open_positions     = {}
         
     
-    def get_price(self, pair, **dummy_inputs):
+    def get_price(self, instrument, **dummy_inputs):
         ''' Returns current price (bid+ask) and home conversion factors.'''
         response = self.api.pricing.get(accountID = self.ACCOUNT_ID, 
-                                   instruments = pair
+                                   instruments = instrument
                                    )
         ask = response.body["prices"][0].closeoutAsk
         bid = response.body["prices"][0].closeoutBid
@@ -90,19 +90,41 @@ class Oanda():
         ''' Cancels pending order by ID. '''
         self.api.order.cancel(accountID = self.ACCOUNT_ID, orderSpecifier=str(order_id))
     
-    def get_open_positions(self, pair = None):
+    def get_open_positions(self, instrument = None):
         ''' Gets the current positions open on the account. '''
         
-        if pair is not None:
-            
-            response = self.api.position.get(accountID = self.ACCOUNT_ID, 
-                                             instrument = pair)
-            # print(response.body['position'])
-        else:
-            response = self.api.position.list_open(accountID = self.ACCOUNT_ID)
-            # print(response.body['positions'][0])
+        response = self.api.trade.list_open(accountID=self.ACCOUNT_ID)
         
-        return response.body
+        oanda_open_trades = response.body['trades']
+        open_trades = {}
+        
+        for order in oanda_open_trades:
+            new_order = {}
+            new_order['order_ID']           = order.id
+            new_order['order_stop_price']   = order.price
+            new_order['order_limit_price']  = order.price
+            new_order['direction']          = np.sign(order.currentUnits)
+            new_order['order_time']         = order.openTime
+            new_order['instrument']         = order.instrument
+            new_order['size']               = order.currentUnits
+            new_order['order_price']        = order.price
+            new_order['entry_price']        = order.price
+            new_order['order_type']         = None
+            new_order['strategy']           = None
+            new_order['granularity']        = None
+            new_order['take_profit']        = None
+            new_order['take_distance']      = None
+            new_order['stop_type']          = None
+            new_order['stop_distance']      = None
+            new_order['stop_loss']          = None
+            new_order['related_orders']     = None
+            
+            if instrument is not None and order.instrument == instrument:
+                open_trades[order.id] = new_order
+            elif instrument is None:
+                open_trades[order.id] = new_order
+        
+        return open_trades
     
     def place_order(self, order_details):
         '''
